==> intel-compute-runtime-debug-25.48.36300.8-1-x86_64.pkg.tar.zst: usr/src/debug/intel-compute-runtime/compute-runtime-25.48.36300.8/shared/source/memory_manager/unified_memory_properties.h <==
/*
 * Copyright (C) 2025 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once
#include "shared/source/helpers/device_bitfield.h"
#include "shared/source/memory_manager/allocation_type.h"
#include "shared/source/unified_memory/unified_memory.h"
#include "shared/source/utilities/stackvec.h"

#include "memory_properties_flags.h"

#include <cstdint>
#include <map>

namespace NEO {

struct UnifiedMemoryProperties {
    UnifiedMemoryProperties(InternalMemoryType memoryType,
                            size_t alignment,
                            const RootDeviceIndicesContainer &rootDeviceIndices,
                            const std::map<uint32_t, DeviceBitfield> &subdeviceBitfields) : memoryType(memoryType),
                                                                                            alignment(alignment),
                                                                                            rootDeviceIndices(rootDeviceIndices),
                                                                                            subdeviceBitfields(subdeviceBitfields){};
    uint32_t getRootDeviceIndex() const;
    InternalMemoryType memoryType = InternalMemoryType::notSpecified;
    MemoryProperties allocationFlags;
    Device *device = nullptr;
    size_t alignment;
    const RootDeviceIndicesContainer &rootDeviceIndices;
    const std::map<uint32_t, DeviceBitfield> &subdeviceBitfields;
    AllocationType requestedAllocationType = AllocationType::unknown;
    bool isInternalAllocation = false;
};

} // namespace NEO

==> intel-compute-runtime-debug-26.05.37020.3-2-x86_64.pkg.tar.zst: usr/src/debug/intel-compute-runtime/compute-runtime-26.05.37020.3/shared/source/memory_manager/unified_memory_properties.h <==
/*
 * Copyright (C) 2025 Intel Corporation
 *
 * SPDX-License-Identifier: MIT
 *
 */

#pragma once
#include "shared/source/helpers/device_bitfield.h"
#include "shared/source/helpers/memory_properties_flags.h"
#include "shared/source/memory_manager/allocation_type.h"
#include "shared/source/unified_memory/unified_memory.h"
#include "shared/source/utilities/stackvec.h"

#include <cstdint>
#include <map>

namespace NEO {

struct UnifiedMemoryProperties {
    UnifiedMemoryProperties(InternalMemoryType memoryType,
                            size_t alignment,
                            const RootDeviceIndicesContainer &rootDeviceIndices,
                            const std::map<uint32_t, DeviceBitfield> &subdeviceBitfields) : memoryType(memoryType),
                                                                                            alignment(alignment),
                                                                                            rootDeviceIndices(rootDeviceIndices),
                                                                                            subdeviceBitfields(subdeviceBitfields){};
    uint32_t getRootDeviceIndex() const;
    InternalMemoryType memoryType = InternalMemoryType::notSpecified;
    MemoryProperties allocationFlags;
    Device *device = nullptr;
    size_t alignment;
    const RootDeviceIndicesContainer &rootDeviceIndices;
    const std::map<uint32_t, DeviceBitfield> &subdeviceBitfields;
    AllocationType requestedAllocationType = AllocationType::unknown;
    bool isInternalAllocation = false;
};

} // namespace NEO
